import React from 'react';
import { DatabaseInfo } from '@graphpolaris/shared/lib/data-access';
import { DatabaseType, SaveStateI, nilUUID } from '@graphpolaris/shared/lib/data-access/api/wsState';

export type SaveStateSampleI = SaveStateI & {
  subtitle: string;
};

export const sampleSaveStates: Array<SaveStateSampleI> = [
  {
    id: nilUUID,
    name: 'Recommendations',
    subtitle: 'Hosted by Neo4j',
    db: {
      username: 'recommendations',
      password: 'recommendations',
      url: 'demo.neo4jlabs.com',
      port: 7687,
      protocol: 'neo4j+s://',
      internalDatabaseName: 'recommendations',
      type: DatabaseType.Neo4j,
    },
  },
  {
    id: nilUUID,
    name: 'Movies',
    subtitle: 'Hosted by Neo4j',
    db: {
      username: 'movies',
      password: 'movies',
      url: 'demo.neo4jlabs.com',
      port: 7687,
      protocol: 'neo4j+s://',
      internalDatabaseName: 'movies',
      type: DatabaseType.Neo4j,
    },
  },
  {
    id: nilUUID,
    name: 'Northwind',
    subtitle: 'Hosted by Neo4j',
    db: {
      username: 'northwind',
      password: 'northwind',
      url: 'demo.neo4jlabs.com',
      port: 7687,
      protocol: 'neo4j+s://',
      internalDatabaseName: 'northwind',
      type: DatabaseType.Neo4j,
    },
  },
  {
    id: nilUUID,
    name: 'Fincen',
    subtitle: 'Hosted by Neo4j',
    db: {
      username: 'fincen',
      password: 'fincen',
      url: 'demo.neo4jlabs.com',
      port: 7687,
      protocol: 'neo4j+s://',
      internalDatabaseName: 'fincen',
      type: DatabaseType.Neo4j,
    },
  },
  {
    id: nilUUID,
    name: 'Slack',
    subtitle: 'Hosted by Neo4j',
    db: {
      username: 'slack',
      password: 'slack',
      url: 'demo.neo4jlabs.com',
      port: 7687,
      protocol: 'neo4j+s://',
      internalDatabaseName: 'slack',
      type: DatabaseType.Neo4j,
    },
  },
  {
    id: nilUUID,
    name: 'Game of Thrones',
    subtitle: 'Hosted by Neo4j',
    db: {
      username: 'gameofthrones',
      password: 'gameofthrones',
      url: 'demo.neo4jlabs.com',
      port: 7687,
      protocol: 'neo4j+s://',
      internalDatabaseName: 'gameofthrones',
      type: DatabaseType.Neo4j,
    },
  },
];

export const SampleDatabaseSelector = (props: { onClick: (data: SaveStateI) => void }) => {
  return (
    <div className="grid grid-cols-2 lg:grid-cols-3 gap-2">
      {sampleSaveStates.map((sample) => (
        <div
          key={sample.name}
          className="card hover:bg-secondary-100 cursor-pointer mb-2 border w-[15rem]"
          onClick={() => props.onClick(sample as SaveStateI)}
        >
          <div className="card-body">
            <h2 className="card-title">{sample.name}</h2>
            <p className="font-light text-secondary-400">{sample.subtitle}</p>
          </div>
        </div>
      ))}
    </div>
  );
};
